"""
MessageView.py
by Jason Conti
February 22, 2010

Displays a notification message in a MessageWindow.
"""

import gtk
import pango

class MessageView(gtk.EventBox):
  """Displays a notification message in a MessageWindow."""
  def __init__(self, message):
    gtk.EventBox.__init__(self)

    self.modify_bg(gtk.STATE_NORMAL, self.get_colormap().alloc_color("white"))

    self._message = message

    self._vbox = gtk.VBox(False)
    self.add(self._vbox)

    self._hbox = gtk.HBox(False)
    self._vbox.pack_start(self._hbox, True, True)

    icon_pixbuf = message.get_icon()
    if icon_pixbuf != None:
      self._icon_image = gtk.image_new_from_pixbuf(icon_pixbuf)
      self._icon_image.set_alignment(0, 0)
      self._icon_image.set_padding(5, 5)
      self._hbox.pack_start(self._icon_image, False, False)

    self._text_vbox = gtk.VBox(False)
    self._hbox.pack_start(self._text_vbox, True, True)

    self._title_label = gtk.Label(message.summary)
    self._title_label.set_alignment(0, 0)
    self._title_label.set_padding(5, 5)
    attr = pango.AttrList()
    attr.insert(pango.AttrWeight(pango.WEIGHT_BOLD, 0, -1))
    self._title_label.set_attributes(attr)
    self._text_vbox.pack_start(self._title_label, False, False)

    self._body_label = MessageBody(message.body)
    self._body_label.set_alignment(0, 0)
    self._body_label.set_padding(5, 5)
    self._body_label.set_line_wrap(True)
    self._text_vbox.pack_start(self._body_label, True, True)

    self._timestamp_label = gtk.Label(message.formatted_timestamp() + " from " + message.app_name)
    self._timestamp_label.set_padding(5, 5)
    attr = pango.AttrList()
    attr.insert(pango.AttrScale(pango.SCALE_SMALL, 0, -1))
    self._timestamp_label.set_attributes(attr)
    self._vbox.pack_start(self._timestamp_label, False, False)

class MessageBody(gtk.Label):
  """Implements a workaround from:
    http://www.16software.com/blog/dynamic-label-wrapping-in-gtk
    that fixes the label overflow problems with a long message body."""
  def __init__(self, text):
    gtk.Label.__init__(self, text)

    self.set_line_wrap(True)
    self.connect("size-allocate", self.on_size_allocate)

  def on_size_allocate(self, widget, rect):
    self.set_size_request(rect.width - 10, -1)
